@@ -1,20 +1,19 @@
+import importlib.resources as pkg_resources
 from json import loads, load, JSONDecodeError
 from pathlib import Path
-import importlib.resources as pkg_resources
 
+from jinja2 import Environment, FileSystemLoader
 from jsonschema.exceptions import ValidationError
 from jsonschema.validators import validate
 from markdown import Markdown
 
-import menagerie
+from menagerie import schemas
 from menagerie.Items.Managers.AbstractManager import AbstractManager
 from menagerie.Items.Pages.AbstractPage import AbstractPage, pretty_title
 from menagerie.Items.Pages.HTMLPage import HTMLPage
 from menagerie.Items.Pages.MDPage import MDPage
 from menagerie.Items.Pages.Schema.JSONSchema import JSONSchema
 from menagerie.Items.Pages.Schema.XMLSchema import XMLSchema
-from jinja2 import Environment, FileSystemLoader
-
 from menagerie.utils.logger import Logger
 
 
@@ -56,7 +55,7 @@ class PageManager(AbstractManager):
         super(PageManager, self).__init__(site_info)
         self.env = Environment(loader=FileSystemLoader(self.gen.settings['content_dir']))
         self.root_dir = Path(self.gen.settings['paths', 'pages'])
-        self.group_schema = loads(pkg_resources.read_text(menagerie, 'folder_schema.json', encoding='utf-8'))
+        self.group_schema = loads(pkg_resources.read_text(schemas, 'folder_schema.json', encoding='utf-8'))
 
     def find(self):
         super(PageManager, self).find()
@@ -64,7 +63,8 @@ class PageManager(AbstractManager):
     def initialize(self):
         for item in self.items:
             item.initialize()
-        self.router = {p.meta['title'].lower(): str(p.out_path.relative_to(self.gen.settings['out_dir']).as_posix()) for p in self.items}
+        self.router = {p.meta['title'].lower(): str(p.out_path.relative_to(self.gen.settings['out_dir']).as_posix()) for
+                       p in self.items}
         self.gen.shared_info['pages'] = self.items
         self.filter_md = Markdown(extensions=['extra'], output_format='html5')
 
@@ -89,7 +89,7 @@ class PageManager(AbstractManager):
                     }
                     if group_config_path.exists():
                         try:
-                            group_config = load(group_config_path)
+                            group_config = loads(group_config_path.read_text(encoding='utf-8'))
                             validate(group_config, self.group_schema)
                             group_meta.update(group_config)
                         except JSONDecodeError as jde:
@@ -111,7 +111,7 @@ class PageManager(AbstractManager):
         filters = {
             'route': self.route,
             'static': self.gen.shared_info['static_filter'],
-            'upper_first': lambda x:   x[0].upper() + x[1:],
+            'upper_first': lambda x: x[0].upper() + x[1:],
             'simple_md': lambda md: self.filter_md.convert(md)
         }
         da_globals = {
